#include <msp430.h> 

#define AD1 0x519//OSEL+CBSTP+RUNSTOP+APNSEL_1+APPSEL_5
#define AD2 0x529//OSEL+CBSTP+RUNSTOP+APNSEL_2+APPSEL_5
#define AD3 0x509//OSEL+CBSTP+RUNSTOP+APNSEL_0+APPSEL_5
#define AD4 0x539//OSEL+CBSTP+RUNSTOP+APNSEL_3+APPSEL_5

#define OUTf 100		//10kHz
#define OUT1 TA0CCR2
#define OUT2 TA0CCR1

#define AuTx0 BIT1//P2.1 P2OUT
#define AuRx0 BIT0//P2.0 P2IN

#define AuTx1 BIT2//P2.2 P2OUT
#define AuRx1 BIT3//P2.3 P2IN

#define ADSETINITIAL {{AD1,AD2,AD3,AD4}, {0,0,0,0}, 0}
typedef struct ADType
{
	int ADSelect[4];
	int ADResult[4];
	int ADPoint	   ;
}ADSetType;

const ADSetType ADSetDefault = ADSETINITIAL;
	  ADSetType ADSet 		 = ADSETINITIAL;

void Init(void);

int main(void) {
    WDTCTL = WDTPW | WDTHOLD;	// Stop watchdog timer
	Init();

    APIE  = EOCIE;              // Enable Interrupt for End of Conversion
    APINT = 0x00 ;              // Clear ADC-DAC-REG

    __bis_SR_register(LPM0_bits);
}

void Init(void)
{
	//Set System & Periphiral Clock
	CCSCTL0 = CCSKEY;						//unLock Control Register
    while (SFRIFG1 & OFIFG)					// Oscillator Flag(s)?
    {
    	CCSCTL7 = 0;                        // Clear HF & LF OSC fault flags
		SFRIFG1 = 0;                        // Clear OFIFG
	}
    CCSCTL2 = 0x0008;						//Set System Clock as 2MHz
    CCSCTL4 = SELA_0 + SELM_0 + SELS_0;		// Select HFCLK/DCO as the source for ACLK, MCLK, and SMCLK
    CCSCTL5 = DIVA_0 + DIVM_0 + DIVS_0;		// Set the Dividers for ACLK, MCLK, and SMCLK to 1
    CCSCTL0_H |= 0xFF;						// Lock CCS

	//Initial AD Port
    APCTL = 0;                                            // Clear APCTL register
    APCNF = CMPON+DBON+CONVON+EOCBU+APREFON+CLKSEL_MCLK;  // Configure A-POOL elements, Select MCLK as A-POOL Clock Source
    APINT = 0x00;                                         // Clear ADC-DAC-REG
	//Initial PWM Port
  	P1SEL0 |= BIT1 + BIT5 + BIT6;	//BIT5:T0.1,BIT6:T1.1
  	P1SEL1 |= BIT1 + BIT5 + BIT6;
  	P1DIR  |= BIT1 + BIT5 + BIT6;

  	TA0CCR0  = OUTf;                          // PWM Period, about 10kHz
  	TA0CCTL1 = OUTMOD_2;                      // TA0CCR1 toggle/reset
  	TA0CCTL2 = OUTMOD_2;                      // TA1CCR1 toggle/set
  	TA0CTL   = TASSEL_2 + MC_3;               // SMCLK, up-down mode

  	OUT1 = OUTf/4  ;
  	OUT2 = OUTf*3/4;
	//Initial Rx/Tx Port

    //Software Initial
    ADSet = ADSetDefault;
}

#pragma vector=APOOL_VECTOR
__interrupt void A_POOL(void)
{
    APIFG = 0;                                        // Clear Interrupt Flag
    ADSet.ADResult[ADSet.ADPoint] = APINT;
    APIE  = EOCIE;
    APINT = 0x00;                                     // Clear ADC-DAC-REG
    APCTL = ADSet.ADSelect[ADSet.ADPoint=(ADSet.ADPoint+1)%4];     // Set Channels and Start Conversion
    OUT1 = (ADSet.ADResult[0]+ADSet.ADResult[2])*100/512;
    OUT2 = (ADSet.ADResult[1]+ADSet.ADResult[3])*100/512;
}
